@@ -16,6 +16,7 @@ import sys
 import re
 import copy
 import importlib
+from io import BytesIO
 from .constants import FALSY_VALUES
 
 # For shell execution
@@ -49,12 +50,14 @@ def gather_tests():
 
 
 def bytes_to_string(data):
-    if isinstance(data, list):
+    if isinstance(data, (list, tuple)):
         return [bytes_to_string(element) for element in data]
     elif isinstance(data, dict):
         return {key: bytes_to_string(value) for key, value in data.items()}
     if isinstance(data, bytes):
         return str(data.hex())
+    if isinstance(data, BytesIO):
+        return data.read().hex()
     else:
         return data
 
